Recorder class final

Controls audio recodfing.

Constructors

Recorder()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isInit → bool
no setter
isRecording → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

init({RecorderFormat format = RecorderFormat.s16, int channelCount = 2, int sampleRate = 44100}) → Future<void>
Initializes the recorder. All parameters directly influence the amount of memory that recording will take.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() → Future<void>
Starts the recorder.
stop() → Future<Recording>
Stops the recorder and returns what have been recorded. Each recording should be disposed when not needed anymore.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited